==> haskell-hspec-golden-0.2.2.0-45-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-golden
version:              0.2.2.0
visibility:           public
id:                   hspec-golden-0.2.2.0-HHLf3mW2jPN7RWmKbQfllB
key:                  hspec-golden-0.2.2.0-HHLf3mW2jPN7RWmKbQfllB
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  a73f0e4a45c9f8d022d15f93dc6e438d
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-golden-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.2.0-HHLf3mW2jPN7RWmKbQfllB
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2
    hspec-core-2.11.4-EJeSUBHzwmhKLMct0Rj4Af

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-golden-0.2.2.0-50-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-golden
version:              0.2.2.0
visibility:           public
id:                   hspec-golden-0.2.2.0-GrLsZaADfPKDPA2JyPp2a2
key:                  hspec-golden-0.2.2.0-GrLsZaADfPKDPA2JyPp2a2
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  619fb4a74f07cf68cbbaa203f222297d
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/hspec-golden-0.2.2.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/hspec-golden-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/hspec-golden-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.2.0-GrLsZaADfPKDPA2JyPp2a2
depends:
    base-4.18.3.0 directory-1.3.8.5 filepath-1.4.301.0
    hspec-core-2.11.4-9GDgSkVcgSWDC61VMQM5Ac

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
